import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { createMessage } from "@/feature/messenger/services/chat/ChatService";
import { getGalleryService } from "@/feature/messenger/services/chat/OptionsMessageService";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import useMessagesStore from "@/feature/messenger/store/chat_store/useMessagesStore";
import { useEffect, useState } from "react"
import toast from 'react-hot-toast';

const useGallery = () => {

    //stores
    const selectedConversation = useConversationsStore(state => state.selectedConversation);
    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const addItemListMessages = useMessagesStore(state => state.actions.addItemListMessages);
    const updateConversation = useConversationsStore(state => state.actions.updateConversation);
    const openModalGallery = useHandleConversationStore(state => state.openModalGallery);
    const handleOpenModalGallery = useHandleConversationStore(state => state.actions.handleOpenModalGallery);

    //states
    //const [openGallery, setOpenGallery] = useState(openModalGallery);
    const [loading, setLoading] = useState(false);
    const [listGallery, setListGallery] = useState([]);
    const [openConfirm, setOpenConfirm] = useState(false);
    const [message, setMessage] = useState('');
    const [resources, setResources] = useState([]);
    const [openDropdown, setOpenDropdown] = useState(false);


    const toggleGallery = () => handleOpenModalGallery();

    const toggleDropdown = () => setOpenDropdown(!openDropdown);

    const toggleConfirm = (messageFile:string) => {
        setOpenConfirm(!openConfirm)
        setMessage(messageFile);
    }

    const toggleConfirmClose = () => {
        setOpenConfirm(!openConfirm)
    }

    const getGallery = async () => {
        setLoading(true)
        const res = await getGalleryService(id_chatbot);
        const response = res
        if (response.success == true) {
            setListGallery(response.data);
        }
        setLoading(false)
        setMessage('');
    }

    const addFileToConversation = async () => {
        setLoading(true)
        createMessage(id_chatbot,selectedConversation.sesion,message).then((res) => {
            const response = res.data.data;          
            if (res.success == true) {
                addItemListMessages(response);
                const currentSesion = selectedConversation;
                currentSesion.conversacion = response.conversacion;
                currentSesion.tipomensaje = response.tipomensaje;
                currentSesion.fecha = response.fecha_sistema;
                updateConversation(currentSesion);   
                toast.success("Se ha enviado el archivo correctamente");
            }else{
                toast.error("No es posible enviar el archivo");
            }
            setOpenConfirm(false)
            handleOpenModalGallery();
            setLoading(false)
            setMessage('');
            setOpenDropdown(false);
            setResources([]);
        });
    }

    const confimSendGallery = () => {
        if (message == '') {
            toast.error("No es posible enviar el archivo");
            return
        }
        addFileToConversation();
    }

    const showResourcesByCategory  = (items:any) => {
        if (items.length == 0) {
            toast.error("No hay recursos para mostrar");
            return
        } else {
            setResources(items);
        }
    }

    const hideListResources = () => {
        setResources([]);
    }

    useEffect(() => {
        if (openModalGallery) {
            getGallery()
        }
    },[openModalGallery])

    return {
        openModalGallery,
        openConfirm,
        openDropdown,
        toggleConfirm,
        toggleGallery,
        toggleDropdown,
        loading,
        resources,
        listGallery,
        confimSendGallery,
        showResourcesByCategory,
        hideListResources,
        toggleConfirmClose
    }
}

export default useGallery